@@ -248,7 +248,7 @@ class mtse:
                 '\nEarly Stopping:', self.early_stop, 'steps')
 
     
-    def train(self, lossf='rmse', plot_results=True, save_plot=True, x_start=10, argmax=False, 
+    def train(self, lossf='rmse', plot_results=True, save_plot=True, x_start=10, argmax=False, CEweights=None,
               predict_strategy=None, save_strategy='best', val_loss_threshold=100., n_iters=100):
         """
         Parameters
@@ -312,6 +312,9 @@ class mtse:
         except:
             criterion = lossf
 
+        if CEweights is not None:
+            criterion = nn.CrossEntropyLoss(torch.tensor(CEweights).to(self.device).float())
+
         for itr in range(1, n_iters + 1):        
             train_loss = 0; train_n = 0
             start_time = time.time()
